@@ -17,6 +17,8 @@ def update_svn_acl(data, project_name):
     if data['person'][LOGIN_NAME] != '':
         acl_parser = ConfigParser()
         svn_authz_path = os.path.join(SVN_PARENT_PATH, project_name.replace(' ', '_').lower(), 'conf/authz')
+        file_name = os.path.basename(data['base_svn_directory']).rsplit('.', 1)[0]
+        base_map_svn_directory = os.path.join(os.path.dirname(data['base_svn_directory']), 'maps', file_name)
         config_helpers.load_config(svn_authz_path, acl_parser)
         svn_service.svn_update_acl(
             base_svn_directory=data['base_svn_directory'],
@@ -24,22 +26,45 @@ def update_svn_acl(data, project_name):
             person=data['person'][LOGIN_NAME],
             permission=data['permission']
         )
+        #set permission for maps folders
+        svn_service.svn_update_acl(
+            base_svn_directory=base_map_svn_directory,
+            acl_parser=acl_parser,
+            person=data['person'][LOGIN_NAME],
+            permission=data['permission']
+        )
         if data['permission'] == 'rw':
             for i in data['dependencies']:
+                dependency_file_name = os.path.basename(i).rsplit('.', 1)[0]
+                dependency_base_map_svn_directory = os.path.join(os.path.dirname(i), 'maps', dependency_file_name)
                 svn_service.svn_update_acl(
                     base_svn_directory=i,
                     acl_parser=acl_parser,
                     person=data['person'][LOGIN_NAME],
                     permission='r'
                 )
+                svn_service.svn_update_acl(
+                    base_svn_directory=dependency_base_map_svn_directory,
+                    acl_parser=acl_parser,
+                    person=data['person'][LOGIN_NAME],
+                    permission='r'
+                )
         elif data['permission'] == 'none':
             for i in data['dependencies']:
+                dependency_file_name = os.path.basename(i).rsplit('.', 1)[0]
+                dependency_base_map_svn_directory = os.path.join(os.path.dirname(i), 'maps', dependency_file_name)
                 svn_service.svn_update_acl(
                     base_svn_directory=i,
                     acl_parser=acl_parser,
                     person=data['person'][LOGIN_NAME],
                     permission='d'
                 )
+                svn_service.svn_update_acl(
+                    base_svn_directory=dependency_base_map_svn_directory,
+                    acl_parser=acl_parser,
+                    person=data['person'][LOGIN_NAME],
+                    permission='d'
+                )
         config_helpers.write_config(svn_authz_path, acl_parser)
 
 class Task(Resource):
