@@ -41,7 +41,7 @@ def svn_mkdir(url, log_message):
     subprocess.run(['svn', 'mkdir', '-m', log_message, url], stdout=subprocess.DEVNULL)
 
 def svn_make_dirs(url, log_message):
-    subprocess.run(['svn', 'mkdir', '-m', '--parents', log_message, url], stdout=subprocess.DEVNULL)
+    subprocess.run(['svn', 'mkdir', '-m', log_message, '--parents', url], stdout=subprocess.DEVNULL)
 
 def svn_import(path, repo_url, log_message):
     subprocess.run(['svn', 'import', '-m', log_message, path, repo_url], stdout=subprocess.DEVNULL)
